﻿SystemOrganization addCategory: #MongostTest!

TestCase subclass: #MgMongoTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MongostTest'!

MgMongoTestCase subclass: #MgBSONTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MongostTest'!

!MgBSONTest methodsFor: 'running' stamp: 'mu 4/15/2011 21:34'!
encodeAndDecode: anObject	
	"Only works with objects for which #= works"
	| actual decode data |
	data := (Dictionary new)
				at: 'k' put: anObject;
				yourself.
	actual := MgBSON write: data.
	decode := MgBSON read: actual readStream.
	self
		assert: (decode at: 'k') = anObject! !

!MgBSONTest methodsFor: 'running' stamp: 'mu 6/21/2011 15:04'!
testDate
	| expected actual decode data |
	expected := #[16 0 0 0 9 107 0 0 0 0 0 0 0 0 0 0].
	data := (Dictionary new)
				at: 'k' put: (MgPortableUtil default newYear: 1970 day: 1);
				yourself.
	actual := MgBSON write: data.
	self assert: expected = actual.
	decode := MgBSON read: actual readStream.
	self
		assert: decode associations asArray = data associations asArray! !

!MgBSONTest methodsFor: 'running' stamp: 'mu 4/15/2011 21:34'!
testEmbeddedDictionary
	| actual decode data subData |
	subData := Dictionary new
		at: 'sk' put: 'v';
		yourself.
	data := Dictionary new
		at: 'k' put: subData;
		yourself.
	actual := MgBSON write: data.
	decode := MgBSON read: actual readStream.
	self assert: decode size = 1.
	self assert: (decode at: 'k') size = 1.
	self assert: ((decode at: 'k') at: 'sk') = 'v'! !

!MgBSONTest methodsFor: 'running' stamp: 'mu 4/15/2011 21:34'!
testEmpty
	| expected actual decode data |
	expected := #[5 0 0 0 0].
	data := Dictionary new.
	actual := MgBSON write: data.
	self assert: expected = actual.
	decode := MgBSON read: actual readStream.
	self
		assert: decode associations asArray = data associations asArray! !

!MgBSONTest methodsFor: 'running' stamp: 'mu 4/15/2011 21:34'!
testMultiple
	| actual data reader t f |
	data := Array with: ((Dictionary new)
						at: 't' put: true;
						yourself)
				with: ((Dictionary new)
						at: 'f' put: false;
						yourself).
	actual := MgBSON writeAll: data.
	reader := actual readStream.
	t := MgBSON read: reader.
	self assert: (t at: 't').
	f := MgBSON read: reader.
	self deny: (f at: 'f')! !

!MgBSONTest methodsFor: 'running' stamp: 'mu 4/15/2011 21:37'!
testOid
	| actual decode data |
	data := (Dictionary new)
				at: 'k' put: (MgOID value: 12345678901234);
				yourself.
	actual := MgBSON write: data.
	decode := MgBSON read: actual readStream.
	self
		assert: decode associations asArray = data associations asArray! !

!MgBSONTest methodsFor: 'running' stamp: 'mu 4/15/2011 21:34'!
testPair
	| expected actual decode data |
	expected := #[14 0 0 0 2 107 0 2 0 0 0 118 0 0].
	data := (Dictionary new)
				at: 'k' put: 'v';
				yourself.
	actual := MgBSON write: data.
	self assert: expected = actual.
	decode := MgBSON read: actual readStream.
	self
		assert: decode associations asArray = data associations asArray! !

!MgBSONTest methodsFor: 'running' stamp: 'mu 4/15/2011 21:34'!
testStringWithEmbeddedNull
	| expected actual data |
	expected := #[14 0 0 0 2 107 0 2 0 0 0 0 0 0].
	data := (Dictionary new)
				at: 'k' put: (String with: (Character value: 0));
				yourself.
	actual := MgBSON write: data.
	self assert: expected = actual.
	self 
		should: [MgBSON read: actual readStream]
		raise: Error! !

!MgBSONTest methodsFor: 'running' stamp: 'mu 4/15/2011 21:34'!
testTwoPair
	| actual decode data |
	data := (Dictionary new)
				at: 'k' put: 'v';
				at: 'l' put: 'w';
				yourself.
	actual := MgBSON write: data.
	decode := MgBSON read: actual readStream.
	self
		assert: decode associations asArray = data associations asArray! !

!MgBSONTest methodsFor: 'running' stamp: 'guest 2/7/2010 19:08'!
testVariousTypes
	"2 raisedTo: 31 2147483648"
	"2 raisedTo: 63 9223372036854775808"
	| values |
	values := #('v' ('v') #v nil true false 1.0d 1 -1 -2 2147483647 2147483648 -2147483648 -2147483649 9223372036854775807 -9223372036854775808).
	values do: [:each | self encodeAndDecode: each]! !

MgMongoTestCase subclass: #MgMongoWholeDatabaseTest
	instanceVariableNames: 'collection root database'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MongostTest'!

MgMongoWholeDatabaseTest subclass: #MgMongoClientTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MongostTest'!

!MgMongoClientTest methodsFor: 'running' stamp: 'mu 4/18/2011 16:23'!
setUp
	root := MgMongo default.
	root open.
	database := root databaseNamed: 'test'.
	collection := database addCollection: 'testCollection'! !

!MgMongoClientTest methodsFor: 'running' stamp: 'guest 2/11/2010 23:42'!
tearDown
	collection drop.
	root close! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testAdd
	| data |
	data := Dictionary new at: 'key' put: 'value'; yourself.
	collection add: data.
	self assert: (collection includes: data)! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testAddAll
	| data |
	data := Array 
		with: (Dictionary new at: 'key' put: 'value'; yourself) 
		with: (Dictionary new at: 'key2' put: 'value2'; yourself).
	collection addAll: data.
	self assert: (collection includes: data first).
	self assert: (collection includes: data last)! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'mu 6/21/2011 15:05'!
testAddMultiByteString
	| mbString data |
	mbString := MgPortableUtil default stringFromBytes: #[227 129 130 227 129 132 227 129 134]. "UTF8 Japanese Hiragana - a, i, u"
	
	data := Dictionary new at: 'key' put: mbString; yourself.
	collection add: data.
	self assert: (collection includes: data)! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testCollectionValidation
	self assert: collection validate isOK! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testCollections
	| new |
	new := database addCollection: 'collection'.
	[self assert: (database collections contains: [:each | each name = 'collection'])]
		ensure: [new drop]! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'mu 4/18/2011 16:27'!
testCursor
	| count data |
	self assert: collection size = 0.
	data := Dictionary new at: 'key' put: 'value'; yourself.
	4 timesRepeat: [collection add: data].
	self assert: collection size = 4.
	count := 0.
	(MgMongoCursor root: root collection: collection qualifiedName query: data block: [:each | count := count + 1] chunkSize: 2) execute.
	self assert: count = 4! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testDatabases
	self assert: (root databases contains: [:each | each name = 'test'])! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testDelete
	| results data |
	data := (Dictionary new)
				at: 'key' put: 'value';
				yourself.
	collection add: data.
	collection delete: data.
	results := collection query: Dictionary new.
	self assert: results size = 0! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testDo
	| count |
	collection add: (Dictionary new at: 'key' put: 'value'; yourself).
	collection add: (Dictionary new at: 'key' put: 'value'; yourself).
	count := 0.
	collection do: [:each | self assert: (each at: 'key') = 'value'. count := count + 1].
	self assert: count = 2! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testError
	"induce an error and make sure an exception is thrown"! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testInjectInto
	collection add: (Dictionary new at: 'key' put: 2; yourself).
	collection add: (Dictionary new at: 'key' put: 3; yourself).
	self assert: (collection inject: 0 into: [:sum :each | sum + (each at: 'key')]) = 5! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testInsertAndQuery
	| results |
	collection add: (Dictionary new at: 'key' put: 'value'; yourself).
	results := collection query: Dictionary new.
	self assert: results size = 1.
	self assert: (results first at: 'key') = 'value'! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testInsertTwoAndQuery
	| results |
	collection add: (Dictionary new at: 'key1' put: 'value1'; yourself).
	collection add: (Dictionary new at: 'key2' put: 'value2'; yourself).
	self assert: collection size = 2.
	results := collection query: Dictionary new.
	self assert: results size = 2! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testIsEmpty
	| data |
	data := Dictionary new at: 'key' put: 'value'; yourself.
	self assert: collection isEmpty.
	collection add: data.
	self deny: collection isEmpty! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testOccurrencesOf
	| data |
	data := (Dictionary new)
				at: 'key1' put: 'value1';
				yourself.
	collection add: data.
	self assert: (collection occurrencesOf: data) = 1! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testRemove
	| data |
	data := Dictionary new at: 'key' put: 'value'; yourself.
	collection add: data.
	self assert: collection size = 1.
	collection remove: data.
	self assert: collection isEmpty! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testRemoveAll
	| data |
	data := Array 
		with: (Dictionary new at: 'key' put: 'value'; yourself) 
		with: (Dictionary new at: 'key2' put: 'value2'; yourself).
	collection addAll: data.
	self assert: collection size = 2.
	collection removeAll: data.
	self assert: collection isEmpty! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testRemoveBoth
	"Unlike regular collections, MongCollection>>remove: is more like copyWithout:,
	removing all instances of the offending element."

	| data |
	data := Dictionary new at: 'key' put: 'value'; yourself.
	collection add: data.
	collection add: data.
	self assert: collection size = 2.
	collection remove: data.
	self assert: collection isEmpty! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testRemoveMissingElementSucceeds
	"Unlike Collection, MongoCollection succeeds if you try to remove a missing element.
	Hence there is no need for remove:ifAbsent:."
	collection add: ((Dictionary new)
				at: 'key1' put: 'value1';
				yourself).
	self assert: collection size = 1.
	collection remove: ((Dictionary new)
				at: 'key2' put: 'value2';
				yourself).
	self assert: collection size = 1 "No exception"! !

!MgMongoClientTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testSelect
	| selected |
	collection add: (Dictionary new at: 'key1' put: 'value1'; yourself).
	collection add: (Dictionary new at: 'key2' put: 'value2'; yourself).
	selected := collection select: (Dictionary new at: 'key1' put: 'value1'; yourself).
	self assert: selected size = 1! !

!MgMongoWholeDatabaseTest methodsFor: 'running' stamp: 'mu 4/18/2011 16:25'!
setUp
	root := MgMongo default.
	root open.
	database := root databaseNamed: 'testWholeDatabase'.
	collection := database addCollection: 'testCollection'! !

!MgMongoWholeDatabaseTest methodsFor: 'running' stamp: 'guest 2/11/2010 23:42'!
tearDown
	database drop.
	root close! !

!MgMongoWholeDatabaseTest methodsFor: 'testing' stamp: 'guest 2/11/2010 23:42'!
testBasics
	self assert: collection validate isOK! !

MgMongoWholeDatabaseTest subclass: #MgSelectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MongostTest'!

!MgSelectTest methodsFor: 'running' stamp: 'mu 4/18/2011 16:23'!
setUp
	root := MgMongo default.
	root open.
	database := root databaseNamed: 'test'.
	collection := database addCollection: 'testCollection'.! !

!MgSelectTest methodsFor: 'running' stamp: 'KentBeck 2/12/2010 18:20'!
tearDown
	collection drop.
	root close! !

!MgSelectTest methodsFor: 'testing' stamp: 'KentBeck 2/12/2010 18:42'!
testQuery
	| uno filtered dos count |
	uno := Dictionary new at: 'key' put: 'uno'; yourself.
	collection add: uno.
	dos := Dictionary new at: 'key' put: 'dos'; yourself.
	collection add: dos.
	filtered := collection select: uno.
	self assert: filtered size = 1.
	count := 0.
	filtered do: [:each | self assert: (each at: 'key') = 'uno'. count := count + 1].
	self assert: count = 1.
"	self assert: (filtered includes: uno).
	self deny: (filtered includes: dos)"! !
